@@ -8,5 +8,5 @@ class ProcessMemoryStoreTestCase(StoreFixture, ExpiringStoreFixture, TestCase):
     store = property(lambda self: self.__store)
     
     def setUp(self):
-        self.__store = ProcessMemoryStore()
+        self.__store = ProcessMemoryStore(lifetime_cb=self.lifetime_cb)
     
\ No newline at end of file
